<?php

class AffiliateWP_MLA_Matrix extends AffiliateWP_MLA_Common {

	public function __construct( $args ) {
		
		parent::__construct();
		
		$this->args = $args;
		$this->matrix_amount = $args['amount'];
		$this->matrix_affiliate_id = $args['affiliate_id'];
		$this->matrix_products = maybe_unserialize( $args['products'] );
	
	}
	
	// Prepare the matrix data.
	public function prepare_matrix_data() {

		$affiliate = new AffiliateWP_MLA_Affiliate( $this->matrix_affiliate_id );

		// Just gets the default (global) matrix settings
		$matrix_aff_settings = $affiliate->get_affiliate_matrix_settings( '', false );
		// Generates the default level variables
		$matrix_level_vars = $affiliate->get_matrix_level_vars( false );
		// Generates the default affiliates for each level
		$matrix_level_affiliates = $affiliate->get_all_level_affiliates();
		
		// Set matrix Data
		$matrix_data = array( 
			'args' => $this->args, // The arguments passed from the insert pending referral filter 
			'direct_affiliate_id' => $this->matrix_affiliate_id,
			'default_matrix_settings' => $matrix_aff_settings,
			'matrix_level_vars' => $matrix_level_vars,
			'matrix_level_affiliates' => $matrix_level_affiliates,
			'matrix_order_total' => $this->get_order_total(),
			'referrals' => array(),
		);
		if( !empty($this->matrix_products) ) $matrix_data['products'] = $this->matrix_products;
		
		// Hook to modify the initial matrix variables
		$matrix_data = apply_filters( 'mla_initial_matrix_data', $matrix_data );
		
		// Generates the default MLA referrals (based on the Global matrix settings)
		if( $matrix_data['matrix_level_vars']['total_levels'] >= 1 ) :
			
			// Loop through the levels
			for( $level = '1'; $level <= $matrix_data['matrix_level_vars']['total_levels']; $level++ ) :
				
				if( isset($matrix_data['matrix_level_affiliates'][$level]) && !empty($matrix_data['matrix_level_affiliates'][$level]) ) :
				
					$affiliate_id = $matrix_data['matrix_level_affiliates'][$level];
					
					$referral_filter_vars = array(
						'affiliate_id' 					=> $affiliate_id,
						//'matrix_order_total'  			=> $matrix_data['matrix_order_total'],
						//'products' 						=> ( !empty($matrix_data['products']) ) ? $matrix_data['products'] : array(),
						//'existing_referral_totals' 		=> ( !empty($matrix_data['referrals']) ) ? $matrix_data['referrals'] : array(),
						//'level_variables' 				=> $matrix_data['matrix_level_vars'],
						'level'							=> $level
					);
					
					// Hook to modify the base amount (order total)
					$referral_base_amount = apply_filters( 'mla_referral_base_amount', $matrix_data['matrix_order_total'], $matrix_data, $referral_filter_vars );
					
					// Check if an affiliate exists on the level
					if( !empty($affiliate_id) && affwp_is_active_affiliate($affiliate_id) ) :
						
						// Hook to disable the MLA referral
						if( apply_filters(' mla_award_referral', (bool) TRUE, $filter_vars ) ) :
						
							$referral_amount = AffiliateWP_MLA_Referral::calculate_referral_amount( $matrix_data['matrix_level_vars']['type'], $matrix_data['matrix_level_vars']['level_rates'][$level], $referral_base_amount );
							
							$default_referral_vars = array(
								'rate_type' => $matrix_data['matrix_level_vars']['type'], 
								'rate_value' => $matrix_data['matrix_level_vars']['level_rates'][$level], 
								'base_amount' => $referral_base_amount
							);
							
							// Hook to modify the calculated referral amount for the level (based on the Global matrix settings)
							// Global product rates hooked here with priority 15
							$referral_amount = apply_filters( 'mla_referral_amount', $referral_amount, $matrix_data, $referral_filter_vars, $default_referral_vars );
							
							// Add the referral to the array
							$matrix_data['referrals'][$level]['affiliate_id'] = $affiliate_id;
							$matrix_data['referrals'][$level]['referral_total'] = $referral_amount;
						
						endif;
						
					endif;
				
				endif;
				
			endfor;
		
		endif;
		
		// Override level 1 when direct referral mode is disabled. Return original referral amount.
		if( $this->matrix_setting( 'direct_referral_mode', $matrix_aff_settings['matrix_setting_id']) != 'mla') :
			$matrix_data['referrals']['1']['referral_total'] = $this->matrix_amount;
		endif;
		
		// Hook to modify the referrals generated by MLA
		$matrix_data['referrals'] = apply_filters( 'mla_referrals', $matrix_data['referrals'], $matrix_data );
		
		// Hook to modify the matrix data to be saved with parent referral and used for generating the MLA commissions
		// Groups add-on (and Group product rates) hooked here with priority 15
		// Team Leaders hooked here with priority 20
		$matrix_data = apply_filters( 'mla_matrix_data', $matrix_data );
		
		$matrix_data['referrals_total'] = $this->get_commissions_total($matrix_data);
		
		return $matrix_data;


	}
	
} // end class
?>